@@ -21,7 +21,6 @@ from typing import (
     Any,
     Generic,
     Iterator,
-    List,
     Mapping,
     NoReturn,
     Optional,
@@ -76,7 +75,7 @@ class CommandCursor(Generic[_DocumentType]):
         if self.__killed:
             self.__end_session(True)
 
-        if "ns" in cursor_info:
+        if "ns" in cursor_info:  # noqa: SIM401
             self.__ns = cursor_info["ns"]
         else:
             self.__ns = collection.full_name
@@ -122,7 +121,7 @@ class CommandCursor(Generic[_DocumentType]):
         """Explicitly close / kill this cursor."""
         self.__die(True)
 
-    def batch_size(self, batch_size: int) -> "CommandCursor[_DocumentType]":
+    def batch_size(self, batch_size: int) -> CommandCursor[_DocumentType]:
         """Limits the number of documents returned in one batch. Each batch
         requires a round trip to the server. It can be adjusted to optimize
         performance and limit data transfer.
@@ -184,8 +183,11 @@ class CommandCursor(Generic[_DocumentType]):
             if exc.code in _CURSOR_CLOSED_ERRORS:
                 # Don't send killCursors because the cursor is already closed.
                 self.__killed = True
-            # Return the session and pinned connection, if necessary.
-            self.close()
+            if exc.timeout:
+                self.__die(False)
+            else:
+                # Return the session and pinned connection, if necessary.
+                self.close()
             raise
         except ConnectionFailure:
             # Don't send killCursors because the cursor is already closed.
@@ -341,7 +343,7 @@ class CommandCursor(Generic[_DocumentType]):
         """
         return self._try_next(get_more_allowed=True)
 
-    def __enter__(self) -> "CommandCursor[_DocumentType]":
+    def __enter__(self) -> CommandCursor[_DocumentType]:
         return self
 
     def __exit__(self, exc_type: Any, exc_val: Any, exc_tb: Any) -> None:
@@ -389,7 +391,7 @@ class RawBatchCommandCursor(CommandCursor, Generic[_DocumentType]):
         codec_options: CodecOptions,
         user_fields: Optional[Mapping[str, Any]] = None,
         legacy_response: bool = False,
-    ) -> List[Mapping[str, Any]]:
+    ) -> list[Mapping[str, Any]]:
         raw_response = response.raw_response(cursor_id, user_fields=user_fields)
         if not legacy_response:
             # OP_MSG returns firstBatch/nextBatch documents as a BSON array
